# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""update null download for transfer plugin

Revision ID: 78c9a733483f
Revises: 5f2672e2233d
Create Date: 2021-11-04 11:08:04.638814

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "78c9a733483f"
down_revision = "5f2672e2233d"
branch_labels = None
depends_on = None

null_script = """#!/bin/sh
./null $*
echo "I am a transfer test!" > null.txt
"""

null_condor = """executable = null.sh
arguments = {{arguments}}

output = null.out
error = null.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin

should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/null

transfer_output_files = .job.ad
+nrao_output_files = "null.txt"
output_destination = nraorsync://{{spool_dir}}
+WantIOProxy = True
{{#remote-cv}}

#run on a condor node in CV-NAASC
requirements = (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}
{{#remote}}
#run on a NMT condor node. (naming consistent with vlass-seci)
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

download_condor = """
executable = test_download.sh
arguments = {{product_locator}} {{request_id}}

output = test_download.out
error = test_download.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/productfetcher, nraorsync://$(SBIN_PATH)/deliver{{#remote-cv}}, nraorsync://{{spool_dir}}/{{profile}}.properties{{/remote-cv}}

+WantIOProxy = True
{{^remote-cv}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True
{{/remote-cv}}
{{#remote-cv}}
environment = "CAPO_PATH=. CAPO_PROFILE={{profile}}"

requirements = HasLustre == True && (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

queue

"""


old_null_script = """#!/bin/sh
./null $*
"""

old_null_condor = """executable = null.sh
arguments = {{arguments}}

output = null.out
error = null.err
log = condor.log
should_transfer_files = yes
transfer_input_files = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin/null

{{#remote-cv}}
#run on a condor node in CV-NAASC
requirements = (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

{{#remote}}
#run on a NMT condor node. (naming consistent with vlass-seci)
requirements = (HasLustre =!= True)
{{/remote}}

queue

"""

old_download_condor = """executable = test_download.sh
arguments = {{product_locator}} {{request_id}}

output = test_download.out
error = test_download.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/deliver{{#remote-cv}}, {{profile}}.properties{{/remote-cv}}

{{^remote-cv}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True
{{/remote-cv}}
{{#remote-cv}}
environment = "CAPO_PATH=. CAPO_PROFILE={{profile}}"

requirements = HasLustre == True && (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

queue

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{null_script}' WHERE filename='null.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{null_condor}' WHERE filename='null.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{download_condor}' WHERE filename='test_download.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_null_script}' WHERE filename='null.sh'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_null_condor}' WHERE filename='null.condor'
            """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_download_condor}' WHERE filename='test_download.condor'
            """
    )
